## 1.8.0.1 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 1.8.0.0 (2023-05-07)

[stubsabot] Bump flake8-2020 to 1.8.* (#10153)

Release: https://pypi.org/pypi/flake8-2020/1.8.0
Homepage: https://github.com/asottile/flake8-2020
Diff: https://github.com/asottile/flake8-2020/compare/v1.7.0...v1.8.0

Stubsabot analysis of the diff between the two releases:
 - 0 public Python files have been added.
 - 0 files included in typeshed's stubs have been deleted.
 - 1 file included in typeshed's stubs has been modified or renamed: `flake8_2020.py`.
 - Total lines of Python code added: 9.
 - Total lines of Python code deleted: 7.

## 1.7.0.2 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 1.7.0.1 (2022-10-15)

Mark `flake8-2020` as complete (#8902)

## 1.7.0 (2022-08-05)

[stubsabot] Bump flake8-2020 to 1.7.* (#8492)

Co-authored-by: stubsabot <>

## 1.6.3 (2022-04-16)

Third-party stubs: import from `collections.abc` where possible (#7637)

## 1.6.2 (2022-01-08)

Use lowercase `type` everywhere (#6853)

## 1.6.0 (2021-12-10)

Add stubs for flake8-2020 (#6555)

